From 4b30c10cef62c07efa1faf8a21e296b4a23ff591 Mon Sep 17 00:00:00 2001
From: lpw <812862340@qq.com>
Date: Wed, 15 Jul 2026 09:35:30 +0800
Subject: [PATCH] 提交版本 4.13.0

---
 frameworks/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADAdSize.h |   77 ++++++++++++++++++++++++++++----------
 1 files changed, 56 insertions(+), 21 deletions(-)

diff --git a/frameworks/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADAdSize.h b/frameworks/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADAdSize.h
index b534e91..fd991a3 100644
--- a/frameworks/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADAdSize.h
+++ b/frameworks/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADAdSize.h
@@ -96,28 +96,28 @@
 
 #pragma mark Anchored Adaptive Sizes
 
-/// Returns a GADAdSize with the given width and a Google-optimized height to create a banner ad.
-/// The size returned has an aspect ratio similar to that of GADAdSizeBanner, suitable for
-/// anchoring near the top or bottom of your app. The height is never larger than 15% of the
-/// device's portrait height and is always between 50-90 points. This function always returns the
-/// same height for any width / device combination.
-FOUNDATION_EXPORT GADAdSize GADPortraitAnchoredAdaptiveBannerAdSizeWithWidth(CGFloat width)
-    NS_SWIFT_NAME(portraitAnchoredAdaptiveBanner(width:));
+/// Returns a GADAdSize with the given width and a Google-optimized height to create a large banner
+/// ad. The size returned is suitable for use in a banner ad anchored near the top or bottom of your
+/// app. The height is never larger than 20% of the device's portrait height and is always between
+/// 50-150 points. This function always returns the same height for any width / device combination.
+/// This function must be called on the main queue.
+FOUNDATION_EXPORT GADAdSize GADLargePortraitAnchoredAdaptiveBannerAdSizeWithWidth(CGFloat width)
+    NS_SWIFT_NAME(largePortraitAnchoredAdaptiveBanner(width:));
 
-/// Returns a GADAdSize with the given width and a Google-optimized height to create a banner ad.
-/// The size returned is suitable for use in a banner ad anchored near the top or bottom of your
-/// app, similar to use of GADAdSizeBanner. The height is never larger than 15% of the devices's
-/// landscape height and is always between 50-90 points. This function always returns the same
-/// height for any width / device combination.
-FOUNDATION_EXPORT GADAdSize GADLandscapeAnchoredAdaptiveBannerAdSizeWithWidth(CGFloat width)
-    NS_SWIFT_NAME(landscapeAnchoredAdaptiveBanner(width:));
+/// Returns a GADAdSize with the given width and a Google-optimized height to create a large banner
+/// ad. The size returned is suitable for use in a banner ad anchored near the top or bottom of your
+/// app. The height is never larger than 20% of the device's landscape height and is always between
+/// 50-150 points. This function always returns the same height for any width / device combination.
+/// This function must be called on the main queue.
+FOUNDATION_EXPORT GADAdSize GADLargeLandscapeAnchoredAdaptiveBannerAdSizeWithWidth(CGFloat width)
+    NS_SWIFT_NAME(largeLandscapeAnchoredAdaptiveBanner(width:));
 
 /// Returns a GADAdSize with the given width and a Google-optimized height. This is a convenience
-/// function to return GADPortraitAnchoredAdaptiveBannerAdSizeWithWidth or
-/// GADLandscapeAnchoredAdaptiveBannerAdSizeWithWidth based on the current interface orientation.
-/// This function must be called on the main queue.
-FOUNDATION_EXPORT GADAdSize GADCurrentOrientationAnchoredAdaptiveBannerAdSizeWithWidth(
-    CGFloat width) NS_SWIFT_NAME(currentOrientationAnchoredAdaptiveBanner(width:));
+/// function to return GADLargePortraitAnchoredAdaptiveBannerAdSizeWithWidth or
+/// GADLargeLandscapeAnchoredAdaptiveBannerAdSizeWithWidth based on the current interface
+/// orientation. This function must be called on the main queue.
+FOUNDATION_EXPORT GADAdSize GADLargeAnchoredAdaptiveBannerAdSizeWithWidth(CGFloat width)
+    NS_SWIFT_NAME(largeAnchoredAdaptiveBanner(width:));
 
 #pragma mark Custom Sizes
 
@@ -169,9 +169,44 @@
 /// An ad size that spans the full width of the application in portrait orientation. The height is
 /// typically 50 points on an iPhone/iPod UI, and 90 points tall on an iPad UI.
 FOUNDATION_EXPORT GADAdSize const kGADAdSizeSmartBannerPortrait
-    GAD_DEPRECATED_MSG_ATTRIBUTE("Use GADPortraitAnchoredAdaptiveBannerAdSizeWithWidth.");
+    GAD_DEPRECATED_MSG_REPLACEMENT_ATTRIBUTE(
+        "Use GADLargePortraitAnchoredAdaptiveBannerAdSizeWithWidth instead.",
+        GADLargePortraitAnchoredAdaptiveBannerAdSizeWithWidth());
 
 /// An ad size that spans the full width of the application in landscape orientation. The height is
 /// typically 32 points on an iPhone/iPod UI, and 90 points tall on an iPad UI.
 FOUNDATION_EXPORT GADAdSize const kGADAdSizeSmartBannerLandscape
-    GAD_DEPRECATED_MSG_ATTRIBUTE("Use GADLandscapeAnchoredAdaptiveBannerAdSizeWithWidth");
+    GAD_DEPRECATED_MSG_REPLACEMENT_ATTRIBUTE(
+        "Use GADLargeLandscapeAnchoredAdaptiveBannerAdSizeWithWidth instead.",
+        GADLargeLandscapeAnchoredAdaptiveBannerAdSizeWithWidth());
+
+/// Returns a GADAdSize with the given width and a Google-optimized height to create a banner ad.
+/// The size returned has an aspect ratio similar to that of GADAdSizeBanner, suitable for
+/// anchoring near the top or bottom of your app. The height is never larger than 15% of the
+/// device's portrait height and is always between 50-90 points. This function always returns the
+/// same height for any width / device combination.
+FOUNDATION_EXPORT GADAdSize GADPortraitAnchoredAdaptiveBannerAdSizeWithWidth(CGFloat width)
+    NS_SWIFT_NAME(portraitAnchoredAdaptiveBanner(width:)) GAD_DEPRECATED_MSG_REPLACEMENT_ATTRIBUTE(
+        "Use GADLargePortraitAnchoredAdaptiveBannerAdSizeWithWidth instead.",
+        GADLargePortraitAnchoredAdaptiveBannerAdSizeWithWidth);
+
+/// Returns a GADAdSize with the given width and a Google-optimized height to create a banner ad.
+/// The size returned is suitable for use in a banner ad anchored near the top or bottom of your
+/// app, similar to use of GADAdSizeBanner. The height is never larger than 15% of the device's
+/// landscape height and is always between 50-90 points. This function always returns the same
+/// height for any width / device combination.
+FOUNDATION_EXPORT GADAdSize GADLandscapeAnchoredAdaptiveBannerAdSizeWithWidth(CGFloat width)
+    NS_SWIFT_NAME(landscapeAnchoredAdaptiveBanner(width:)) GAD_DEPRECATED_MSG_REPLACEMENT_ATTRIBUTE(
+        "Use GADLargeLandscapeAnchoredAdaptiveBannerAdSizeWithWidth instead.",
+        GADLargeLandscapeAnchoredAdaptiveBannerAdSizeWithWidth);
+
+/// Returns a GADAdSize with the given width and a Google-optimized height. This is a convenience
+/// function to return GADPortraitAnchoredAdaptiveBannerAdSizeWithWidth or
+/// GADLandscapeAnchoredAdaptiveBannerAdSizeWithWidth based on the current interface orientation.
+/// This function must be called on the main queue.
+FOUNDATION_EXPORT GADAdSize
+GADCurrentOrientationAnchoredAdaptiveBannerAdSizeWithWidth(CGFloat width)
+    NS_SWIFT_NAME(currentOrientationAnchoredAdaptiveBanner(width:))
+        GAD_DEPRECATED_MSG_REPLACEMENT_ATTRIBUTE(
+            "Use GADLargeAnchoredAdaptiveBannerAdSizeWithWidth instead.",
+            GADLargeAnchoredAdaptiveBannerAdSizeWithWidth);

--
Gitblit v1.8.0